Digest

Struct Digest 

pub struct Digest(/* private fields */);
This is a cryptographic hash of everything in a crate, which reliably identifies its exact source code

Implementations

Source

impl Digest

pub fn as_slice(&self) -> &[u8]

pub fn from_bytes(bytes: &[u8]) -> Option<Self>

pub fn into_vec(self) -> Vec<u8>