pub struct Package {
pub common: Common,
pub package: PackageInfo,
pub diff_base: Option<PackageInfo>,
pub issues: Vec<Issue>,
pub advisories: Vec<Advisory>,
pub flags: Flags,
pub alternatives: HashSet<PackageId>,
pub comment: String,
// some fields omitted
}Expand description
Body of a Package Review Proof
Fields
common: Commonpackage: PackageInfodiff_base: Option<PackageInfo>issues: Vec<Issue>advisories: Vec<Advisory>flags: Flagsalternatives: HashSet<PackageId>comment: StringImplementations
Get the Review
This forces the user to handle reviews that are empty (everything is set to None) explicitly.
Get the underlying review.
The caller is responsible for handling the case where
review.is_none().