pub struct LlmAgentInfo {
pub model: String,
pub model_version: Option<String>,
pub human_guided: bool,
}Expand description
Information about an LLM agent that performed the review.
Presence of this field in a review proof (code or package) indicates that the review was conducted by (or with assistance of) an LLM agent.
Fields
model: StringModel identifier (e.g. “claude-opus-4-6”, “gpt-4o”)
model_version: Option<String>Model version string, if available (e.g. “2026-04-01”)
human_guided: boolWhether a human guided the agent during the review (interactive session), as opposed to a fully autonomous review.