pub struct Draft { /* fields omitted */ }Expand description
A Proof Content Draft
A simplified version of content, used for user interaction - editing the parts that are not neccessary for the user to see.
pub struct Draft { /* fields omitted */ }A Proof Content Draft
A simplified version of content, used for user interaction - editing the parts that are not neccessary for the user to see.